==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta2StatefulSetUpdateStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1beta2StatefulSetUpdateStrategyFluent<A extends V1beta2StatefulSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1beta2RollingUpdateStatefulSetStrategy getRollingUpdate();
    public V1beta2RollingUpdateStatefulSetStrategy buildRollingUpdate();
    public A withRollingUpdate(V1beta2RollingUpdateStatefulSetStrategy rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item);
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta2RollingUpdateStatefulSetStrategyFluent<V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta2StatefulSetUpdateStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta2StatefulSetUpdateStrategyFluent<A extends V1beta2StatefulSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1beta2RollingUpdateStatefulSetStrategy getRollingUpdate();
    public V1beta2RollingUpdateStatefulSetStrategy buildRollingUpdate();
    public A withRollingUpdate(V1beta2RollingUpdateStatefulSetStrategy rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item);
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta2RollingUpdateStatefulSetStrategyFluent<V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}
